@@ -23,7 +23,6 @@
 #define plugin_webarchiver_h
 
 #include <kparts/plugin.h>
-#include <klibloader.h>
 
 class PluginWebArchiver : public KParts::Plugin
 {
@@ -32,7 +31,7 @@ class PluginWebArchiver : public KParts::Plugin
 public:
     PluginWebArchiver(QObject *parent,
                       const QVariantList &);
-    virtual ~PluginWebArchiver();
+    ~PluginWebArchiver() override;
 
 public slots:
     void slotSaveToArchive();
