@@ -52,7 +52,7 @@
 #include "konqueror_interface.h"
 #include "konqhistorymanager.h"
 
-KConfig *KonqCombo::s_config = 0L;
+KConfig *KonqCombo::s_config = nullptr;
 const int KonqCombo::temporary = 0;
 
 static QString titleOfURL(const QString &urlStr)
@@ -76,10 +76,10 @@ class KonqListWidgetItem : public QListWidgetItem
 public:
     enum { KonqItemType = 0x1845D5CC };
 
-    KonqListWidgetItem(QListWidget *parent = Q_NULLPTR);
-    KonqListWidgetItem(const QString &text, QListWidget *parent = Q_NULLPTR);
+    KonqListWidgetItem(QListWidget *parent = nullptr);
+    KonqListWidgetItem(const QString &text, QListWidget *parent = nullptr);
 
-    QVariant data(int role) const Q_DECL_OVERRIDE;
+    QVariant data(int role) const override;
 
     bool reuse(const QString &newText);
 
@@ -93,8 +93,8 @@ class KonqComboItemDelegate : public QItemDelegate
 {
 public:
     KonqComboItemDelegate(QObject *parent) : QItemDelegate(parent) {}
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
-    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 };
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -102,11 +102,11 @@ public:
 class KonqComboLineEdit : public KLineEdit
 {
 public:
-    KonqComboLineEdit(QWidget *parent = Q_NULLPTR);
-    KCompletionBox *completionBox(bool create) Q_DECL_OVERRIDE;
+    KonqComboLineEdit(QWidget *parent = nullptr);
+    KCompletionBox *completionBox(bool create) override;
 
 protected:
-    void mouseDoubleClickEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+    void mouseDoubleClickEvent(QMouseEvent *e) override;
 };
 
 class KonqComboCompletionBox : public KCompletionBox
