@@ -25,6 +25,8 @@
 #include "webenginepart.h"
 #include "webenginepartkiohandler.h"
 
+#include <webenginepart_debug.h>
+
 //#include <QWebHistoryItem>
 #include <QWebEngineSettings>
 #include <QWebEngineProfile>
@@ -44,8 +46,8 @@
 #include "ui/featurepermissionbar.h"
 #include "settings/webenginesettings.h"
 
-#include <kcodecaction.h>
-#include <kio/global.h>
+#include <KCodecAction>
+#include <KIO/Global>
 
 #include <KActionCollection>
 #include <KAboutData>
@@ -82,11 +84,11 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
              m_emitOpenUrlNotify(true),
              m_hasCachedFormData(false),
              m_doLoadFinishedActions(false),
-             m_statusBarWalletLabel(0),
-             m_searchBar(0),
-             m_passwordBar(0),
-             m_featurePermissionBar(0),
-             m_wallet(Q_NULLPTR)
+             m_statusBarWalletLabel(nullptr),
+             m_searchBar(nullptr),
+             m_passwordBar(nullptr),
+             m_featurePermissionBar(nullptr),
+             m_wallet(nullptr)
 {
     QWebEngineProfile *prof = QWebEngineProfile::defaultProfile();
     if (!prof->urlSchemeHandler("error")) {
@@ -191,14 +193,14 @@ WebEnginePage* WebEnginePart::page()
 {
     if (m_webView)
         return qobject_cast<WebEnginePage*>(m_webView->page());
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 const WebEnginePage* WebEnginePart::page() const
 {
     if (m_webView)
         return qobject_cast<const WebEnginePage*>(m_webView->page());
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 void WebEnginePart::initActions()
@@ -321,7 +323,7 @@ void WebEnginePart::connectWebEnginePageSignals(WebEnginePage* page)
     connect(page, &QWebEnginePage::iconUrlChanged, [page, this](const QUrl& url) {
         if (WebEngineSettings::self()->favIconsEnabled()
             && !page->profile()->isOffTheRecord()){
-                m_browserExtension->setIconUrl(url);
+                emit m_browserExtension->setIconUrl(url);
         }
     });
 }
@@ -361,8 +363,6 @@ bool WebEnginePart::openUrl(const QUrl &_u)
 {
     QUrl u (_u);
 
-    qDebug() << u;
-
     // Ignore empty requests...
     if (u.isEmpty())
         return false;
@@ -413,7 +413,7 @@ bool WebEnginePart::closeUrl()
     return true;
 }
 
-QWebEngineView* WebEnginePart::view()
+QWebEngineView* WebEnginePart::view() const
 {
     return m_webView;
 }
@@ -444,7 +444,7 @@ void WebEnginePart::slotLoadStarted()
 {
     if(!Utils::isBlankUrl(url()))
     {
-        emit started(0);
+        emit started(nullptr);
     }
     updateActions();
 
@@ -492,7 +492,7 @@ void WebEnginePart::slotLoadFinished (bool ok)
         } 
         else {
 // Attempt to fill the web form...
-            WebEngineWallet *wallet = page() ? page()->wallet() : 0;
+            WebEngineWallet *wallet = page() ? page()->wallet() : nullptr;
             if (wallet){
                 wallet->fillFormData(page());
             }
@@ -558,7 +558,7 @@ void WebEnginePart::slotShowSecurity()
 
     const WebSslInfo& sslInfo = page()->sslInfo();
     if (!sslInfo.isValid()) {
-        KMessageBox::information(0, i18n("The SSL information for this site "
+        KMessageBox::information(nullptr, i18n("The SSL information for this site "
                                     "appears to be corrupt."),
                             i18nc("Secure Sockets Layer", "SSL"));
         return;
@@ -764,13 +764,13 @@ void WebEnginePart::slotWalletClosed()
 
     m_statusBarExtension->removeStatusBarItem(m_statusBarWalletLabel);
     delete m_statusBarWalletLabel;
-    m_statusBarWalletLabel = 0;
+    m_statusBarWalletLabel = nullptr;
     m_hasCachedFormData = false;
 }
 
 void WebEnginePart::slotShowWalletMenu()
 {
-    QMenu *menu = new QMenu(0);
+    QMenu *menu = new QMenu(nullptr);
 
     if (m_webView && WebEngineSettings::self()->isNonPasswordStorableSite(m_webView->url().host()))
       menu->addAction(i18n("&Allow password caching for this site"), this, SLOT(slotDeleteNonPasswordStorableSite()));
@@ -819,7 +819,7 @@ void WebEnginePart::slotSetTextEncoding(QTextCodec * codec)
     if (!localSettings)
         return;
 
-    qDebug() << "Encoding: new=>" << localSettings->defaultTextEncoding() << ", old=>" << codec->name();
+    qCDebug(WEBENGINEPART_LOG) << "Encoding: new=>" << localSettings->defaultTextEncoding() << ", old=>" << codec->name();
 
     localSettings->setDefaultTextEncoding(codec->name());
     page()->triggerAction(QWebEnginePage::Reload);
@@ -899,7 +899,7 @@ void WebEnginePart::slotSaveFormDataRequested (const QString& key, const QUrl& u
     if (!m_passwordBar) {
         m_passwordBar = new PasswordBar(widget());
         if (!m_wallet) {
-            qDebug() << "No m_wallet instance found! This should never happen!";
+            qCWarning(WEBENGINEPART_LOG) << "No m_wallet instance found! This should never happen!";
             return;
         }
         connect(m_passwordBar, SIGNAL(saveFormDataAccepted(QString)),
